# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'bulk_update_firmware.ui',
# licensing of 'bulk_update_firmware.ui' applies.
#
# Created: Fri Oct 25 09:11:18 2019
#      by: pyside2-uic  running on PySide2 5.13.1
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_BulkUpdateFirmwareDialog(object):
    def setupUi(self, BulkUpdateFirmwareDialog):
        BulkUpdateFirmwareDialog.setObjectName("BulkUpdateFirmwareDialog")
        BulkUpdateFirmwareDialog.resize(387, 262)
        self.gridLayout = QtWidgets.QGridLayout(BulkUpdateFirmwareDialog)
        self.gridLayout.setObjectName("gridLayout")
        self.firmwareLabel = QtWidgets.QLabel(BulkUpdateFirmwareDialog)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.firmwareLabel.setFont(font)
        self.firmwareLabel.setObjectName("firmwareLabel")
        self.gridLayout.addWidget(self.firmwareLabel, 0, 0, 1, 4)
        spacerItem = QtWidgets.QSpacerItem(20, 13, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem, 1, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.firmwareLocation = QtWidgets.QLineEdit(BulkUpdateFirmwareDialog)
        self.firmwareLocation.setObjectName("firmwareLocation")
        self.horizontalLayout.addWidget(self.firmwareLocation)
        self.browseButton = QtWidgets.QPushButton(BulkUpdateFirmwareDialog)
        self.browseButton.setObjectName("browseButton")
        self.horizontalLayout.addWidget(self.browseButton)
        self.gridLayout.addLayout(self.horizontalLayout, 1, 1, 1, 3)
        self.serialRangeLabel = QtWidgets.QLabel(BulkUpdateFirmwareDialog)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.serialRangeLabel.setFont(font)
        self.serialRangeLabel.setObjectName("serialRangeLabel")
        self.gridLayout.addWidget(self.serialRangeLabel, 2, 0, 1, 4)
        self.minSerialLabel = QtWidgets.QLabel(BulkUpdateFirmwareDialog)
        self.minSerialLabel.setObjectName("minSerialLabel")
        self.gridLayout.addWidget(self.minSerialLabel, 3, 1, 1, 2)
        self.minSerial = QtWidgets.QSpinBox(BulkUpdateFirmwareDialog)
        self.minSerial.setMaximum(2147483647)
        self.minSerial.setObjectName("minSerial")
        self.gridLayout.addWidget(self.minSerial, 3, 3, 1, 1)
        self.maxSerialLabel = QtWidgets.QLabel(BulkUpdateFirmwareDialog)
        self.maxSerialLabel.setObjectName("maxSerialLabel")
        self.gridLayout.addWidget(self.maxSerialLabel, 4, 1, 1, 2)
        self.maxSerial = QtWidgets.QSpinBox(BulkUpdateFirmwareDialog)
        self.maxSerial.setMaximum(2147483647)
        self.maxSerial.setProperty("value", 2147483647)
        self.maxSerial.setObjectName("maxSerial")
        self.gridLayout.addWidget(self.maxSerial, 4, 3, 1, 1)
        self.setDeviceModeLabel = QtWidgets.QLabel(BulkUpdateFirmwareDialog)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.setDeviceModeLabel.setFont(font)
        self.setDeviceModeLabel.setObjectName("setDeviceModeLabel")
        self.gridLayout.addWidget(self.setDeviceModeLabel, 6, 0, 1, 4)
        self.setDeviceMode = QtWidgets.QCheckBox(BulkUpdateFirmwareDialog)
        self.setDeviceMode.setObjectName("setDeviceMode")
        self.gridLayout.addWidget(self.setDeviceMode, 7, 1, 1, 3)
        spacerItem1 = QtWidgets.QSpacerItem(20, 13, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem1, 8, 1, 1, 1)
        self.deviceModeLabel = QtWidgets.QLabel(BulkUpdateFirmwareDialog)
        self.deviceModeLabel.setEnabled(False)
        self.deviceModeLabel.setObjectName("deviceModeLabel")
        self.gridLayout.addWidget(self.deviceModeLabel, 8, 2, 1, 1)
        self.deviceMode = QtWidgets.QSpinBox(BulkUpdateFirmwareDialog)
        self.deviceMode.setEnabled(False)
        self.deviceMode.setMaximum(255)
        self.deviceMode.setProperty("value", 2)
        self.deviceMode.setObjectName("deviceMode")
        self.gridLayout.addWidget(self.deviceMode, 8, 3, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(369, 2, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem2, 9, 0, 1, 4)
        self.buttonBox = QtWidgets.QDialogButtonBox(BulkUpdateFirmwareDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 10, 0, 1, 4)
        self.radioStrengthLabel = QtWidgets.QLabel(BulkUpdateFirmwareDialog)
        self.radioStrengthLabel.setObjectName("radioStrengthLabel")
        self.gridLayout.addWidget(self.radioStrengthLabel, 5, 1, 1, 2)
        self.radioStrength = QtWidgets.QSpinBox(BulkUpdateFirmwareDialog)
        self.radioStrength.setMinimum(-100)
        self.radioStrength.setMaximum(0)
        self.radioStrength.setProperty("value", -100)
        self.radioStrength.setObjectName("radioStrength")
        self.gridLayout.addWidget(self.radioStrength, 5, 3, 1, 1)
        self.gridLayout.setColumnStretch(2, 1)

        self.retranslateUi(BulkUpdateFirmwareDialog)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("accepted()"), BulkUpdateFirmwareDialog.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("rejected()"), BulkUpdateFirmwareDialog.reject)
        QtCore.QObject.connect(self.setDeviceMode, QtCore.SIGNAL("toggled(bool)"), self.deviceModeLabel.setEnabled)
        QtCore.QObject.connect(self.setDeviceMode, QtCore.SIGNAL("toggled(bool)"), self.deviceMode.setEnabled)
        QtCore.QMetaObject.connectSlotsByName(BulkUpdateFirmwareDialog)
        BulkUpdateFirmwareDialog.setTabOrder(self.firmwareLocation, self.browseButton)
        BulkUpdateFirmwareDialog.setTabOrder(self.browseButton, self.minSerial)
        BulkUpdateFirmwareDialog.setTabOrder(self.minSerial, self.maxSerial)
        BulkUpdateFirmwareDialog.setTabOrder(self.maxSerial, self.setDeviceMode)
        BulkUpdateFirmwareDialog.setTabOrder(self.setDeviceMode, self.deviceMode)
        BulkUpdateFirmwareDialog.setTabOrder(self.deviceMode, self.buttonBox)

    def retranslateUi(self, BulkUpdateFirmwareDialog):
        BulkUpdateFirmwareDialog.setWindowTitle(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Bulk Update Firmware", None, -1))
        self.firmwareLabel.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Firmware", None, -1))
        self.browseButton.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Browse...", None, -1))
        self.serialRangeLabel.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Device Filtering", None, -1))
        self.minSerialLabel.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Minimum SN", None, -1))
        self.maxSerialLabel.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Maximum SN", None, -1))
        self.setDeviceModeLabel.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Set Device Mode", None, -1))
        self.setDeviceMode.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Set Device Mode After Update", None, -1))
        self.deviceModeLabel.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Device Mode", None, -1))
        self.radioStrengthLabel.setText(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", "Minimum Radio Strength", None, -1))
        self.radioStrength.setSuffix(QtWidgets.QApplication.translate("BulkUpdateFirmwareDialog", " dBm", None, -1))

