# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'calibration_channel.ui',
# licensing of 'calibration_channel.ui' applies.
#
# Created: Tue Mar  3 13:57:37 2020
#      by: pyside2-uic  running on PySide2 5.13.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_CalibrationChannel(object):
    def setupUi(self, CalibrationChannel):
        CalibrationChannel.setObjectName("CalibrationChannel")
        CalibrationChannel.resize(195, 254)
        self.verticalLayout = QtWidgets.QVBoxLayout(CalibrationChannel)
        self.verticalLayout.setObjectName("verticalLayout")
        self.calibrationEnabled = QtWidgets.QCheckBox(CalibrationChannel)
        self.calibrationEnabled.setChecked(True)
        self.calibrationEnabled.setObjectName("calibrationEnabled")
        self.verticalLayout.addWidget(self.calibrationEnabled)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.unitLabel = QtWidgets.QLabel(CalibrationChannel)
        self.unitLabel.setObjectName("unitLabel")
        self.horizontalLayout_3.addWidget(self.unitLabel)
        self.unit = QtWidgets.QLabel(CalibrationChannel)
        self.unit.setObjectName("unit")
        self.horizontalLayout_3.addWidget(self.unit)
        spacerItem = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem)
        self.selectUnit = QtWidgets.QPushButton(CalibrationChannel)
        self.selectUnit.setObjectName("selectUnit")
        self.horizontalLayout_3.addWidget(self.selectUnit)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.acRadioButton = QtWidgets.QRadioButton(CalibrationChannel)
        self.acRadioButton.setChecked(True)
        self.acRadioButton.setObjectName("acRadioButton")
        self.horizontalLayout_2.addWidget(self.acRadioButton)
        self.linearRadioButton = QtWidgets.QRadioButton(CalibrationChannel)
        self.linearRadioButton.setObjectName("linearRadioButton")
        self.horizontalLayout_2.addWidget(self.linearRadioButton)
        spacerItem1 = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem1)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.stackedWidget = QtWidgets.QStackedWidget(CalibrationChannel)
        self.stackedWidget.setObjectName("stackedWidget")
        self.linearPage = QtWidgets.QWidget()
        self.linearPage.setObjectName("linearPage")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.linearPage)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.linearCapture = QtWidgets.QPushButton(self.linearPage)
        self.linearCapture.setObjectName("linearCapture")
        self.horizontalLayout_5.addWidget(self.linearCapture)
        spacerItem2 = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem2)
        self.plotButton = QtWidgets.QPushButton(self.linearPage)
        self.plotButton.setEnabled(False)
        self.plotButton.setObjectName("plotButton")
        self.horizontalLayout_5.addWidget(self.plotButton)
        self.verticalLayout_2.addLayout(self.horizontalLayout_5)
        self.linearTable = QtWidgets.QTableWidget(self.linearPage)
        self.linearTable.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.linearTable.setSelectionMode(QtWidgets.QAbstractItemView.NoSelection)
        self.linearTable.setHorizontalScrollMode(QtWidgets.QAbstractItemView.ScrollPerPixel)
        self.linearTable.setObjectName("linearTable")
        self.linearTable.setColumnCount(3)
        self.linearTable.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.linearTable.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.linearTable.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.linearTable.setHorizontalHeaderItem(2, item)
        self.verticalLayout_2.addWidget(self.linearTable)
        self.stackedWidget.addWidget(self.linearPage)
        self.acPage = QtWidgets.QWidget()
        self.acPage.setObjectName("acPage")
        self.formLayout = QtWidgets.QFormLayout(self.acPage)
        self.formLayout.setContentsMargins(0, 0, 0, 0)
        self.formLayout.setObjectName("formLayout")
        self.capturedMagnitudeLabel = QtWidgets.QLabel(self.acPage)
        self.capturedMagnitudeLabel.setObjectName("capturedMagnitudeLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.capturedMagnitudeLabel)
        self.capturedOffsetLabel = QtWidgets.QLabel(self.acPage)
        self.capturedOffsetLabel.setObjectName("capturedOffsetLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.capturedOffsetLabel)
        self.actualMagnitudeLabel = QtWidgets.QLabel(self.acPage)
        self.actualMagnitudeLabel.setObjectName("actualMagnitudeLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.actualMagnitudeLabel)
        self.actualOffsetLabel = QtWidgets.QLabel(self.acPage)
        self.actualOffsetLabel.setObjectName("actualOffsetLabel")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.actualOffsetLabel)
        self.capturedMagnitude = UnitFormatterDoubleSpinBox(self.acPage)
        self.capturedMagnitude.setObjectName("capturedMagnitude")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.capturedMagnitude)
        self.actualMagnitude = UnitFormatterDoubleSpinBox(self.acPage)
        self.actualMagnitude.setObjectName("actualMagnitude")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.actualMagnitude)
        self.capturedOffset = UnitFormatterDoubleSpinBox(self.acPage)
        self.capturedOffset.setObjectName("capturedOffset")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.capturedOffset)
        self.actualOffset = UnitFormatterDoubleSpinBox(self.acPage)
        self.actualOffset.setObjectName("actualOffset")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.actualOffset)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.acCapture = QtWidgets.QPushButton(self.acPage)
        self.acCapture.setObjectName("acCapture")
        self.horizontalLayout_4.addWidget(self.acCapture)
        spacerItem3 = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem3)
        self.formLayout.setLayout(0, QtWidgets.QFormLayout.SpanningRole, self.horizontalLayout_4)
        self.stackedWidget.addWidget(self.acPage)
        self.verticalLayout.addWidget(self.stackedWidget)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSpacing(6)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.scaleLabel = QtWidgets.QLabel(CalibrationChannel)
        self.scaleLabel.setObjectName("scaleLabel")
        self.horizontalLayout.addWidget(self.scaleLabel)
        self.scale = QtWidgets.QLineEdit(CalibrationChannel)
        self.scale.setReadOnly(True)
        self.scale.setObjectName("scale")
        self.horizontalLayout.addWidget(self.scale)
        self.offsetLabel = QtWidgets.QLabel(CalibrationChannel)
        self.offsetLabel.setObjectName("offsetLabel")
        self.horizontalLayout.addWidget(self.offsetLabel)
        self.offset = QtWidgets.QLineEdit(CalibrationChannel)
        self.offset.setReadOnly(True)
        self.offset.setObjectName("offset")
        self.horizontalLayout.addWidget(self.offset)
        self.verticalLayout.addLayout(self.horizontalLayout)

        self.retranslateUi(CalibrationChannel)
        self.stackedWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(CalibrationChannel)
        CalibrationChannel.setTabOrder(self.calibrationEnabled, self.selectUnit)
        CalibrationChannel.setTabOrder(self.selectUnit, self.acRadioButton)
        CalibrationChannel.setTabOrder(self.acRadioButton, self.linearRadioButton)
        CalibrationChannel.setTabOrder(self.linearRadioButton, self.acCapture)
        CalibrationChannel.setTabOrder(self.acCapture, self.capturedMagnitude)
        CalibrationChannel.setTabOrder(self.capturedMagnitude, self.capturedOffset)
        CalibrationChannel.setTabOrder(self.capturedOffset, self.actualMagnitude)
        CalibrationChannel.setTabOrder(self.actualMagnitude, self.actualOffset)
        CalibrationChannel.setTabOrder(self.actualOffset, self.linearCapture)
        CalibrationChannel.setTabOrder(self.linearCapture, self.linearTable)
        CalibrationChannel.setTabOrder(self.linearTable, self.scale)
        CalibrationChannel.setTabOrder(self.scale, self.offset)

    def retranslateUi(self, CalibrationChannel):
        self.calibrationEnabled.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Calibrate channel", None, -1))
        self.unitLabel.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Unit:", None, -1))
        self.unit.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Unit", None, -1))
        self.selectUnit.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Select Unit", None, -1))
        self.acRadioButton.setText(QtWidgets.QApplication.translate("CalibrationChannel", "AC RMS", None, -1))
        self.linearRadioButton.setText(QtWidgets.QApplication.translate("CalibrationChannel", "1st Order Linear", None, -1))
        self.linearCapture.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Capture", None, -1))
        self.plotButton.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Plot", None, -1))
        self.linearTable.horizontalHeaderItem(0).setText(QtWidgets.QApplication.translate("CalibrationChannel", "Captured", None, -1))
        self.linearTable.horizontalHeaderItem(1).setText(QtWidgets.QApplication.translate("CalibrationChannel", "Actual", None, -1))
        self.linearTable.horizontalHeaderItem(2).setText(QtWidgets.QApplication.translate("CalibrationChannel", "Delete", None, -1))
        self.capturedMagnitudeLabel.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Captured RMS Magnitude", None, -1))
        self.capturedOffsetLabel.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Captured DC Offset", None, -1))
        self.actualMagnitudeLabel.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Actual RMS Magnitude", None, -1))
        self.actualOffsetLabel.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Actual DC Offset", None, -1))
        self.acCapture.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Capture", None, -1))
        self.scaleLabel.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Scale", None, -1))
        self.offsetLabel.setText(QtWidgets.QApplication.translate("CalibrationChannel", "Offset", None, -1))

from hyperborea.unit_formatter_spinbox import UnitFormatterDoubleSpinBox
