# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'plotmain.ui',
# licensing of 'plotmain.ui' applies.
#
# Created: Fri Mar 27 12:36:09 2020
#      by: pyside2-uic  running on PySide2 5.13.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_PlotMainWindow(object):
    def setupUi(self, PlotMainWindow):
        PlotMainWindow.setObjectName("PlotMainWindow")
        PlotMainWindow.resize(1200, 800)
        self.centralwidget = QtWidgets.QWidget(PlotMainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setContentsMargins(2, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget.setObjectName("tabWidget")
        self.verticalLayout.addWidget(self.tabWidget)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setSpacing(6)
        self.horizontalLayout_2.setContentsMargins(3, -1, 3, 1)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.warningLabel = QtWidgets.QLabel(self.centralwidget)
        self.warningLabel.setStyleSheet("QLabel { color : red ; font-weight : bold ; font-size : 18px ; }")
        self.warningLabel.setObjectName("warningLabel")
        self.horizontalLayout_2.addWidget(self.warningLabel)
        self.uploadRateLabel = QtWidgets.QLabel(self.centralwidget)
        self.uploadRateLabel.setMinimumSize(QtCore.QSize(75, 25))
        self.uploadRateLabel.setObjectName("uploadRateLabel")
        self.horizontalLayout_2.addWidget(self.uploadRateLabel)
        self.uploadProgress = QtWidgets.QProgressBar(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uploadProgress.sizePolicy().hasHeightForWidth())
        self.uploadProgress.setSizePolicy(sizePolicy)
        self.uploadProgress.setMinimumSize(QtCore.QSize(175, 25))
        self.uploadProgress.setMaximum(5957928)
        self.uploadProgress.setProperty("value", 2359296)
        self.uploadProgress.setAlignment(QtCore.Qt.AlignCenter)
        self.uploadProgress.setObjectName("uploadProgress")
        self.horizontalLayout_2.addWidget(self.uploadProgress)
        self.uploadNameLabel = QtWidgets.QLabel(self.centralwidget)
        self.uploadNameLabel.setObjectName("uploadNameLabel")
        self.horizontalLayout_2.addWidget(self.uploadNameLabel)
        spacerItem = QtWidgets.QSpacerItem(0, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.datetimeLabel = QtWidgets.QLabel(self.centralwidget)
        self.datetimeLabel.setObjectName("datetimeLabel")
        self.horizontalLayout_2.addWidget(self.datetimeLabel)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        PlotMainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(PlotMainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1200, 21))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuStreaming = QtWidgets.QMenu(self.menubar)
        self.menuStreaming.setObjectName("menuStreaming")
        self.menuSettings = QtWidgets.QMenu(self.menubar)
        self.menuSettings.setObjectName("menuSettings")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        self.menuCheckForUpdates = QtWidgets.QMenu(self.menuHelp)
        self.menuCheckForUpdates.setObjectName("menuCheckForUpdates")
        self.menuDevices = QtWidgets.QMenu(self.menubar)
        self.menuDevices.setObjectName("menuDevices")
        self.menuTools = QtWidgets.QMenu(self.menubar)
        self.menuTools.setObjectName("menuTools")
        self.menuMarkForUpload = QtWidgets.QMenu(self.menuTools)
        self.menuMarkForUpload.setObjectName("menuMarkForUpload")
        PlotMainWindow.setMenuBar(self.menubar)
        self.toolBar = QtWidgets.QToolBar(PlotMainWindow)
        self.toolBar.setMovable(False)
        self.toolBar.setIconSize(QtCore.QSize(32, 32))
        self.toolBar.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.toolBar.setFloatable(False)
        self.toolBar.setObjectName("toolBar")
        PlotMainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.actionRescanUSB = QtWidgets.QAction(PlotMainWindow)
        self.actionRescanUSB.setObjectName("actionRescanUSB")
        self.actionExit = QtWidgets.QAction(PlotMainWindow)
        self.actionExit.setObjectName("actionExit")
        self.actionPreferences = QtWidgets.QAction(PlotMainWindow)
        self.actionPreferences.setObjectName("actionPreferences")
        self.actionAbout = QtWidgets.QAction(PlotMainWindow)
        self.actionAbout.setObjectName("actionAbout")
        self.actionDisableStreaming = QtWidgets.QAction(PlotMainWindow)
        self.actionDisableStreaming.setCheckable(True)
        self.actionDisableStreaming.setObjectName("actionDisableStreaming")
        self.actionDisableArchiving = QtWidgets.QAction(PlotMainWindow)
        self.actionDisableArchiving.setCheckable(True)
        self.actionDisableArchiving.setObjectName("actionDisableArchiving")
        self.actionFindTCPDevices = QtWidgets.QAction(PlotMainWindow)
        self.actionFindTCPDevices.setObjectName("actionFindTCPDevices")
        self.actionEnableRFPower = QtWidgets.QAction(PlotMainWindow)
        self.actionEnableRFPower.setObjectName("actionEnableRFPower")
        self.actionDisableRFPower = QtWidgets.QAction(PlotMainWindow)
        self.actionDisableRFPower.setObjectName("actionDisableRFPower")
        self.actionPause = QtWidgets.QAction(PlotMainWindow)
        self.actionPause.setCheckable(True)
        self.actionPause.setObjectName("actionPause")
        self.actionResume = QtWidgets.QAction(PlotMainWindow)
        self.actionResume.setCheckable(True)
        self.actionResume.setObjectName("actionResume")
        self.actionClosableTabs = QtWidgets.QAction(PlotMainWindow)
        self.actionClosableTabs.setCheckable(True)
        self.actionClosableTabs.setObjectName("actionClosableTabs")
        self.actionUpdateLatestStable = QtWidgets.QAction(PlotMainWindow)
        self.actionUpdateLatestStable.setObjectName("actionUpdateLatestStable")
        self.actionUpdateSpecificBranch = QtWidgets.QAction(PlotMainWindow)
        self.actionUpdateSpecificBranch.setObjectName("actionUpdateSpecificBranch")
        self.actionUpdateSpecificCommit = QtWidgets.QAction(PlotMainWindow)
        self.actionUpdateSpecificCommit.setObjectName("actionUpdateSpecificCommit")
        self.actionUpdateCurrentBranch = QtWidgets.QAction(PlotMainWindow)
        self.actionUpdateCurrentBranch.setObjectName("actionUpdateCurrentBranch")
        self.actionDownloadFirmware = QtWidgets.QAction(PlotMainWindow)
        self.actionDownloadFirmware.setObjectName("actionDownloadFirmware")
        self.actionMarkFiles = QtWidgets.QAction(PlotMainWindow)
        self.actionMarkFiles.setObjectName("actionMarkFiles")
        self.actionMarkDirectory = QtWidgets.QAction(PlotMainWindow)
        self.actionMarkDirectory.setObjectName("actionMarkDirectory")
        self.menuFile.addAction(self.actionExit)
        self.menuStreaming.addAction(self.actionDisableStreaming)
        self.menuStreaming.addAction(self.actionDisableArchiving)
        self.menuSettings.addAction(self.actionClosableTabs)
        self.menuSettings.addAction(self.actionPreferences)
        self.menuCheckForUpdates.addAction(self.actionUpdateLatestStable)
        self.menuCheckForUpdates.addAction(self.actionUpdateCurrentBranch)
        self.menuCheckForUpdates.addAction(self.actionUpdateSpecificBranch)
        self.menuCheckForUpdates.addAction(self.actionUpdateSpecificCommit)
        self.menuHelp.addAction(self.menuCheckForUpdates.menuAction())
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.actionAbout)
        self.menuDevices.addAction(self.actionRescanUSB)
        self.menuDevices.addAction(self.actionFindTCPDevices)
        self.menuMarkForUpload.addAction(self.actionMarkFiles)
        self.menuMarkForUpload.addAction(self.actionMarkDirectory)
        self.menuTools.addAction(self.actionDownloadFirmware)
        self.menuTools.addSeparator()
        self.menuTools.addAction(self.menuMarkForUpload.menuAction())
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuDevices.menuAction())
        self.menubar.addAction(self.menuStreaming.menuAction())
        self.menubar.addAction(self.menuSettings.menuAction())
        self.menubar.addAction(self.menuTools.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())
        self.toolBar.addAction(self.actionEnableRFPower)
        self.toolBar.addAction(self.actionDisableRFPower)
        self.toolBar.addAction(self.actionRescanUSB)
        self.toolBar.addAction(self.actionFindTCPDevices)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionPause)
        self.toolBar.addAction(self.actionResume)

        self.retranslateUi(PlotMainWindow)
        QtCore.QObject.connect(self.actionExit, QtCore.SIGNAL("triggered()"), PlotMainWindow.close)
        QtCore.QMetaObject.connectSlotsByName(PlotMainWindow)

    def retranslateUi(self, PlotMainWindow):
        PlotMainWindow.setWindowTitle(QtWidgets.QApplication.translate("PlotMainWindow", "Acheron", None, -1))
        self.warningLabel.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Warning: Archiving Disabled", None, -1))
        self.uploadRateLabel.setText(QtWidgets.QApplication.translate("PlotMainWindow", "350 kB/s", None, -1))
        self.uploadProgress.setFormat(QtWidgets.QApplication.translate("PlotMainWindow", "%v/%m (%p%)", None, -1))
        self.uploadNameLabel.setText(QtWidgets.QApplication.translate("PlotMainWindow", "20181029T2241Z_HSS2143.apd", None, -1))
        self.datetimeLabel.setText(QtWidgets.QApplication.translate("PlotMainWindow", "0000-00-00T00:00:00Z", None, -1))
        self.menuFile.setTitle(QtWidgets.QApplication.translate("PlotMainWindow", "File", None, -1))
        self.menuStreaming.setTitle(QtWidgets.QApplication.translate("PlotMainWindow", "Streaming", None, -1))
        self.menuSettings.setTitle(QtWidgets.QApplication.translate("PlotMainWindow", "Settings", None, -1))
        self.menuHelp.setTitle(QtWidgets.QApplication.translate("PlotMainWindow", "Help", None, -1))
        self.menuCheckForUpdates.setTitle(QtWidgets.QApplication.translate("PlotMainWindow", "Check for Updates", None, -1))
        self.menuDevices.setTitle(QtWidgets.QApplication.translate("PlotMainWindow", "Devices", None, -1))
        self.menuTools.setTitle(QtWidgets.QApplication.translate("PlotMainWindow", "Tools", None, -1))
        self.menuMarkForUpload.setTitle(QtWidgets.QApplication.translate("PlotMainWindow", "Mark for Upload", None, -1))
        self.actionRescanUSB.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Rescan USB", None, -1))
        self.actionExit.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Exit", None, -1))
        self.actionPreferences.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Preferences...", None, -1))
        self.actionAbout.setText(QtWidgets.QApplication.translate("PlotMainWindow", "About...", None, -1))
        self.actionDisableStreaming.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Disable Streaming", None, -1))
        self.actionDisableArchiving.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Disable Archiving", None, -1))
        self.actionFindTCPDevices.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Find TCP Devices...", None, -1))
        self.actionEnableRFPower.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Enable RF Power (0)", None, -1))
        self.actionDisableRFPower.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Disable RF Power (0)", None, -1))
        self.actionPause.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Pause", None, -1))
        self.actionResume.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Resume", None, -1))
        self.actionClosableTabs.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Easy Close Tabs", None, -1))
        self.actionClosableTabs.setToolTip(QtWidgets.QApplication.translate("PlotMainWindow", "Easy Close Tabs", None, -1))
        self.actionUpdateLatestStable.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Latest Stable", None, -1))
        self.actionUpdateSpecificBranch.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Specific Branch...", None, -1))
        self.actionUpdateSpecificCommit.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Specific Commit..", None, -1))
        self.actionUpdateCurrentBranch.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Latest branch", None, -1))
        self.actionDownloadFirmware.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Download Firmware...", None, -1))
        self.actionDownloadFirmware.setToolTip(QtWidgets.QApplication.translate("PlotMainWindow", "Download Firmware...", None, -1))
        self.actionMarkFiles.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Mark Files...", None, -1))
        self.actionMarkFiles.setToolTip(QtWidgets.QApplication.translate("PlotMainWindow", "Mark Files...", None, -1))
        self.actionMarkDirectory.setText(QtWidgets.QApplication.translate("PlotMainWindow", "Mark Directory...", None, -1))
        self.actionMarkDirectory.setToolTip(QtWidgets.QApplication.translate("PlotMainWindow", "Mark Directory...", None, -1))

