# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'preferences.ui',
# licensing of 'preferences.ui' applies.
#
# Created: Fri Mar 27 10:12:20 2020
#      by: pyside2-uic  running on PySide2 5.13.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_PreferencesDialog(object):
    def setupUi(self, PreferencesDialog):
        PreferencesDialog.setObjectName("PreferencesDialog")
        PreferencesDialog.resize(414, 379)
        self.verticalLayout = QtWidgets.QVBoxLayout(PreferencesDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tabWidget = QtWidgets.QTabWidget(PreferencesDialog)
        self.tabWidget.setObjectName("tabWidget")
        self.streamingTab = QtWidgets.QWidget()
        self.streamingTab.setObjectName("streamingTab")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.streamingTab)
        self.gridLayout_3.setObjectName("gridLayout_3")
        spacerItem = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem, 1, 0, 1, 1)
        self.automaticRGBCheckBox = QtWidgets.QCheckBox(self.streamingTab)
        self.automaticRGBCheckBox.setChecked(True)
        self.automaticRGBCheckBox.setObjectName("automaticRGBCheckBox")
        self.gridLayout_3.addWidget(self.automaticRGBCheckBox, 1, 1, 1, 1)
        self.ledsLabel = QtWidgets.QLabel(self.streamingTab)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.ledsLabel.setFont(font)
        self.ledsLabel.setObjectName("ledsLabel")
        self.gridLayout_3.addWidget(self.ledsLabel, 0, 0, 1, 2)
        spacerItem1 = QtWidgets.QSpacerItem(369, 243, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_3.addItem(spacerItem1, 5, 0, 1, 2)
        self.downsamplingLabel = QtWidgets.QLabel(self.streamingTab)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.downsamplingLabel.setFont(font)
        self.downsamplingLabel.setObjectName("downsamplingLabel")
        self.gridLayout_3.addWidget(self.downsamplingLabel, 2, 0, 1, 2)
        self.downsampleCheckBox = QtWidgets.QCheckBox(self.streamingTab)
        self.downsampleCheckBox.setChecked(True)
        self.downsampleCheckBox.setObjectName("downsampleCheckBox")
        self.gridLayout_3.addWidget(self.downsampleCheckBox, 3, 1, 1, 1)
        self.tabWidget.addTab(self.streamingTab, "")
        self.unitTab = QtWidgets.QWidget()
        self.unitTab.setObjectName("unitTab")
        self.gridLayout = QtWidgets.QGridLayout(self.unitTab)
        self.gridLayout.setObjectName("gridLayout")
        self.unitsLabel = QtWidgets.QLabel(self.unitTab)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.unitsLabel.setFont(font)
        self.unitsLabel.setObjectName("unitsLabel")
        self.gridLayout.addWidget(self.unitsLabel, 0, 0, 1, 2)
        spacerItem2 = QtWidgets.QSpacerItem(20, 13, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem2, 1, 0, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem3, 4, 0, 1, 2)
        self.unitPreferences = UnitPreferencesWidget(self.unitTab)
        self.unitPreferences.setObjectName("unitPreferences")
        self.gridLayout.addWidget(self.unitPreferences, 1, 1, 1, 1)
        self.tabWidget.addTab(self.unitTab, "")
        self.outputTab = QtWidgets.QWidget()
        self.outputTab.setObjectName("outputTab")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.outputTab)
        self.gridLayout_2.setObjectName("gridLayout_2")
        spacerItem4 = QtWidgets.QSpacerItem(369, 237, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem4, 6, 0, 1, 3)
        self.outputLocationLabel = QtWidgets.QLabel(self.outputTab)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.outputLocationLabel.setFont(font)
        self.outputLocationLabel.setObjectName("outputLocationLabel")
        self.gridLayout_2.addWidget(self.outputLocationLabel, 0, 0, 1, 3)
        self.compressionLevel = QtWidgets.QSpinBox(self.outputTab)
        self.compressionLevel.setMinimum(0)
        self.compressionLevel.setMaximum(9)
        self.compressionLevel.setProperty("value", 6)
        self.compressionLevel.setObjectName("compressionLevel")
        self.gridLayout_2.addWidget(self.compressionLevel, 5, 2, 1, 1)
        self.compressionLabel = QtWidgets.QLabel(self.outputTab)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.compressionLabel.setFont(font)
        self.compressionLabel.setObjectName("compressionLabel")
        self.gridLayout_2.addWidget(self.compressionLabel, 3, 0, 1, 3)
        self.compressionLevelLabel = QtWidgets.QLabel(self.outputTab)
        self.compressionLevelLabel.setObjectName("compressionLevelLabel")
        self.gridLayout_2.addWidget(self.compressionLevelLabel, 5, 1, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.outputLocation = QtWidgets.QLineEdit(self.outputTab)
        self.outputLocation.setObjectName("outputLocation")
        self.horizontalLayout.addWidget(self.outputLocation)
        self.browseButton = QtWidgets.QPushButton(self.outputTab)
        self.browseButton.setObjectName("browseButton")
        self.horizontalLayout.addWidget(self.browseButton)
        self.gridLayout_2.addLayout(self.horizontalLayout, 1, 1, 1, 2)
        spacerItem5 = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem5, 1, 0, 1, 1)
        self.gridLayout_2.setColumnStretch(1, 1)
        self.tabWidget.addTab(self.outputTab, "")
        self.uploadTab = QtWidgets.QWidget()
        self.uploadTab.setObjectName("uploadTab")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.uploadTab)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.uploadAccessKeyID = QtWidgets.QLineEdit(self.uploadTab)
        self.uploadAccessKeyID.setEnabled(False)
        self.uploadAccessKeyID.setObjectName("uploadAccessKeyID")
        self.gridLayout_4.addWidget(self.uploadAccessKeyID, 5, 3, 1, 1)
        self.uploadAccessKeyIDLabel = QtWidgets.QLabel(self.uploadTab)
        self.uploadAccessKeyIDLabel.setEnabled(False)
        self.uploadAccessKeyIDLabel.setObjectName("uploadAccessKeyIDLabel")
        self.gridLayout_4.addWidget(self.uploadAccessKeyIDLabel, 5, 2, 1, 1)
        spacerItem6 = QtWidgets.QSpacerItem(20, 13, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem6, 2, 1, 1, 1)
        self.enableUpload = QtWidgets.QCheckBox(self.uploadTab)
        self.enableUpload.setObjectName("enableUpload")
        self.gridLayout_4.addWidget(self.enableUpload, 1, 1, 1, 3)
        self.uploadSecretAccessKey = QtWidgets.QLineEdit(self.uploadTab)
        self.uploadSecretAccessKey.setEnabled(False)
        self.uploadSecretAccessKey.setEchoMode(QtWidgets.QLineEdit.PasswordEchoOnEdit)
        self.uploadSecretAccessKey.setObjectName("uploadSecretAccessKey")
        self.gridLayout_4.addWidget(self.uploadSecretAccessKey, 6, 3, 1, 1)
        self.s3BucketLabel = QtWidgets.QLabel(self.uploadTab)
        self.s3BucketLabel.setEnabled(False)
        self.s3BucketLabel.setObjectName("s3BucketLabel")
        self.gridLayout_4.addWidget(self.s3BucketLabel, 2, 2, 1, 1)
        self.uploadLabel = QtWidgets.QLabel(self.uploadTab)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.uploadLabel.setFont(font)
        self.uploadLabel.setObjectName("uploadLabel")
        self.gridLayout_4.addWidget(self.uploadLabel, 0, 0, 1, 3)
        self.uploadDirectoryLabel = QtWidgets.QLabel(self.uploadTab)
        self.uploadDirectoryLabel.setEnabled(False)
        self.uploadDirectoryLabel.setObjectName("uploadDirectoryLabel")
        self.gridLayout_4.addWidget(self.uploadDirectoryLabel, 4, 2, 1, 1)
        self.uploadDirectory = QtWidgets.QLineEdit(self.uploadTab)
        self.uploadDirectory.setEnabled(False)
        self.uploadDirectory.setObjectName("uploadDirectory")
        self.gridLayout_4.addWidget(self.uploadDirectory, 4, 3, 1, 1)
        spacerItem7 = QtWidgets.QSpacerItem(20, 13, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem7, 1, 0, 1, 1)
        spacerItem8 = QtWidgets.QSpacerItem(369, 116, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_4.addItem(spacerItem8, 8, 0, 1, 4)
        self.s3Bucket = QtWidgets.QLineEdit(self.uploadTab)
        self.s3Bucket.setEnabled(False)
        self.s3Bucket.setObjectName("s3Bucket")
        self.gridLayout_4.addWidget(self.s3Bucket, 2, 3, 1, 1)
        self.uploadDeleteOriginal = QtWidgets.QCheckBox(self.uploadTab)
        self.uploadDeleteOriginal.setEnabled(False)
        self.uploadDeleteOriginal.setObjectName("uploadDeleteOriginal")
        self.gridLayout_4.addWidget(self.uploadDeleteOriginal, 7, 2, 1, 2)
        self.uploadSecretAccessKeyLabel = QtWidgets.QLabel(self.uploadTab)
        self.uploadSecretAccessKeyLabel.setEnabled(False)
        self.uploadSecretAccessKeyLabel.setObjectName("uploadSecretAccessKeyLabel")
        self.gridLayout_4.addWidget(self.uploadSecretAccessKeyLabel, 6, 2, 1, 1)
        self.awsRegionLabel = QtWidgets.QLabel(self.uploadTab)
        self.awsRegionLabel.setEnabled(False)
        self.awsRegionLabel.setObjectName("awsRegionLabel")
        self.gridLayout_4.addWidget(self.awsRegionLabel, 3, 2, 1, 1)
        self.awsRegion = QtWidgets.QLineEdit(self.uploadTab)
        self.awsRegion.setEnabled(False)
        self.awsRegion.setObjectName("awsRegion")
        self.gridLayout_4.addWidget(self.awsRegion, 3, 3, 1, 1)
        self.tabWidget.addTab(self.uploadTab, "")
        self.verticalLayout.addWidget(self.tabWidget)
        self.buttonBox = QtWidgets.QDialogButtonBox(PreferencesDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(PreferencesDialog)
        self.tabWidget.setCurrentIndex(1)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("accepted()"), PreferencesDialog.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("rejected()"), PreferencesDialog.reject)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.s3BucketLabel.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.s3Bucket.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.uploadDirectoryLabel.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.uploadDirectory.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.uploadAccessKeyIDLabel.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.uploadAccessKeyID.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.uploadSecretAccessKeyLabel.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.uploadSecretAccessKey.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.uploadDeleteOriginal.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.awsRegionLabel.setEnabled)
        QtCore.QObject.connect(self.enableUpload, QtCore.SIGNAL("toggled(bool)"), self.awsRegion.setEnabled)
        QtCore.QMetaObject.connectSlotsByName(PreferencesDialog)
        PreferencesDialog.setTabOrder(self.tabWidget, self.automaticRGBCheckBox)
        PreferencesDialog.setTabOrder(self.automaticRGBCheckBox, self.outputLocation)
        PreferencesDialog.setTabOrder(self.outputLocation, self.browseButton)
        PreferencesDialog.setTabOrder(self.browseButton, self.compressionLevel)
        PreferencesDialog.setTabOrder(self.compressionLevel, self.enableUpload)
        PreferencesDialog.setTabOrder(self.enableUpload, self.s3Bucket)
        PreferencesDialog.setTabOrder(self.s3Bucket, self.awsRegion)
        PreferencesDialog.setTabOrder(self.awsRegion, self.uploadDirectory)
        PreferencesDialog.setTabOrder(self.uploadDirectory, self.uploadAccessKeyID)
        PreferencesDialog.setTabOrder(self.uploadAccessKeyID, self.uploadSecretAccessKey)
        PreferencesDialog.setTabOrder(self.uploadSecretAccessKey, self.uploadDeleteOriginal)
        PreferencesDialog.setTabOrder(self.uploadDeleteOriginal, self.buttonBox)

    def retranslateUi(self, PreferencesDialog):
        PreferencesDialog.setWindowTitle(QtWidgets.QApplication.translate("PreferencesDialog", "Preferences", None, -1))
        self.automaticRGBCheckBox.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Automatically set RGB LEDs when connecting/disconnecting", None, -1))
        self.ledsLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "RGB LEDs", None, -1))
        self.downsamplingLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Downsampling", None, -1))
        self.downsampleCheckBox.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Downsample high speed channels (for time domain graph only)", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.streamingTab), QtWidgets.QApplication.translate("PreferencesDialog", "Streaming", None, -1))
        self.unitsLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Display Units", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.unitTab), QtWidgets.QApplication.translate("PreferencesDialog", "Units", None, -1))
        self.outputLocationLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Output Location", None, -1))
        self.compressionLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Compression", None, -1))
        self.compressionLevelLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Compression Level (default 6)", None, -1))
        self.browseButton.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Browse...", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.outputTab), QtWidgets.QApplication.translate("PreferencesDialog", "Output", None, -1))
        self.uploadAccessKeyIDLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "AWS Access Key ID", None, -1))
        self.enableUpload.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Enable AWS S3 Upload", None, -1))
        self.s3BucketLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "S3 Bucket", None, -1))
        self.uploadLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Amazon S3 Upload", None, -1))
        self.uploadDirectoryLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Upload Directory", None, -1))
        self.uploadDeleteOriginal.setText(QtWidgets.QApplication.translate("PreferencesDialog", "Delete original .apd after successful upload", None, -1))
        self.uploadSecretAccessKeyLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "AWS Secret Access Key", None, -1))
        self.awsRegionLabel.setText(QtWidgets.QApplication.translate("PreferencesDialog", "S3 Bucket AWS Region", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.uploadTab), QtWidgets.QApplication.translate("PreferencesDialog", "Cloud Upload", None, -1))

from hyperborea.unit_preferences import UnitPreferencesWidget
