# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'rgb_control_widget.ui',
# licensing of 'rgb_control_widget.ui' applies.
#
# Created: Sun Mar 31 19:42:18 2019
#      by: pyside2-uic  running on PySide2 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_RGBControlWidget(object):
    def setupUi(self, RGBControlWidget):
        RGBControlWidget.setObjectName("RGBControlWidget")
        RGBControlWidget.resize(239, 192)
        self.verticalLayout = QtWidgets.QVBoxLayout(RGBControlWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.whiteButton = QtWidgets.QPushButton(RGBControlWidget)
        self.whiteButton.setObjectName("whiteButton")
        self.gridLayout.addWidget(self.whiteButton, 0, 1, 1, 1)
        self.redButton = QtWidgets.QPushButton(RGBControlWidget)
        self.redButton.setObjectName("redButton")
        self.gridLayout.addWidget(self.redButton, 1, 0, 1, 1)
        self.greenButton = QtWidgets.QPushButton(RGBControlWidget)
        self.greenButton.setObjectName("greenButton")
        self.gridLayout.addWidget(self.greenButton, 1, 1, 1, 1)
        self.blueButton = QtWidgets.QPushButton(RGBControlWidget)
        self.blueButton.setObjectName("blueButton")
        self.gridLayout.addWidget(self.blueButton, 1, 2, 1, 1)
        self.cyanButton = QtWidgets.QPushButton(RGBControlWidget)
        self.cyanButton.setObjectName("cyanButton")
        self.gridLayout.addWidget(self.cyanButton, 2, 0, 1, 1)
        self.magentaButton = QtWidgets.QPushButton(RGBControlWidget)
        self.magentaButton.setObjectName("magentaButton")
        self.gridLayout.addWidget(self.magentaButton, 2, 1, 1, 1)
        self.yellowButton = QtWidgets.QPushButton(RGBControlWidget)
        self.yellowButton.setObjectName("yellowButton")
        self.gridLayout.addWidget(self.yellowButton, 2, 2, 1, 1)
        self.blackButton = QtWidgets.QPushButton(RGBControlWidget)
        self.blackButton.setObjectName("blackButton")
        self.gridLayout.addWidget(self.blackButton, 3, 1, 1, 1)
        self.verticalLayout.addLayout(self.gridLayout)
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.blueLabel = QtWidgets.QLabel(RGBControlWidget)
        self.blueLabel.setObjectName("blueLabel")
        self.gridLayout_2.addWidget(self.blueLabel, 2, 0, 1, 1)
        self.blueSlider = QtWidgets.QSlider(RGBControlWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.blueSlider.sizePolicy().hasHeightForWidth())
        self.blueSlider.setSizePolicy(sizePolicy)
        self.blueSlider.setMinimumSize(QtCore.QSize(128, 0))
        self.blueSlider.setMaximum(255)
        self.blueSlider.setOrientation(QtCore.Qt.Horizontal)
        self.blueSlider.setObjectName("blueSlider")
        self.gridLayout_2.addWidget(self.blueSlider, 2, 1, 1, 1)
        self.blueSpinBox = QtWidgets.QSpinBox(RGBControlWidget)
        self.blueSpinBox.setMaximum(255)
        self.blueSpinBox.setObjectName("blueSpinBox")
        self.gridLayout_2.addWidget(self.blueSpinBox, 2, 2, 1, 1)
        self.greenLabel = QtWidgets.QLabel(RGBControlWidget)
        self.greenLabel.setObjectName("greenLabel")
        self.gridLayout_2.addWidget(self.greenLabel, 1, 0, 1, 1)
        self.redSpinBox = QtWidgets.QSpinBox(RGBControlWidget)
        self.redSpinBox.setMaximum(255)
        self.redSpinBox.setObjectName("redSpinBox")
        self.gridLayout_2.addWidget(self.redSpinBox, 0, 2, 1, 1)
        self.redLabel = QtWidgets.QLabel(RGBControlWidget)
        self.redLabel.setObjectName("redLabel")
        self.gridLayout_2.addWidget(self.redLabel, 0, 0, 1, 1)
        self.redSlider = QtWidgets.QSlider(RGBControlWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.redSlider.sizePolicy().hasHeightForWidth())
        self.redSlider.setSizePolicy(sizePolicy)
        self.redSlider.setMinimumSize(QtCore.QSize(128, 0))
        self.redSlider.setMaximum(255)
        self.redSlider.setOrientation(QtCore.Qt.Horizontal)
        self.redSlider.setObjectName("redSlider")
        self.gridLayout_2.addWidget(self.redSlider, 0, 1, 1, 1)
        self.greenSpinBox = QtWidgets.QSpinBox(RGBControlWidget)
        self.greenSpinBox.setMaximum(255)
        self.greenSpinBox.setObjectName("greenSpinBox")
        self.gridLayout_2.addWidget(self.greenSpinBox, 1, 2, 1, 1)
        self.greenSlider = QtWidgets.QSlider(RGBControlWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.greenSlider.sizePolicy().hasHeightForWidth())
        self.greenSlider.setSizePolicy(sizePolicy)
        self.greenSlider.setMinimumSize(QtCore.QSize(128, 0))
        self.greenSlider.setMaximum(255)
        self.greenSlider.setOrientation(QtCore.Qt.Horizontal)
        self.greenSlider.setObjectName("greenSlider")
        self.gridLayout_2.addWidget(self.greenSlider, 1, 1, 1, 1)
        self.verticalLayout.addLayout(self.gridLayout_2)
        self.blueLabel.setBuddy(self.blueSlider)
        self.greenLabel.setBuddy(self.greenSlider)
        self.redLabel.setBuddy(self.redSlider)

        self.retranslateUi(RGBControlWidget)
        QtCore.QObject.connect(self.redSlider, QtCore.SIGNAL("valueChanged(int)"), self.redSpinBox.setValue)
        QtCore.QObject.connect(self.greenSlider, QtCore.SIGNAL("valueChanged(int)"), self.greenSpinBox.setValue)
        QtCore.QObject.connect(self.blueSlider, QtCore.SIGNAL("valueChanged(int)"), self.blueSpinBox.setValue)
        QtCore.QObject.connect(self.redSpinBox, QtCore.SIGNAL("valueChanged(int)"), self.redSlider.setValue)
        QtCore.QObject.connect(self.greenSpinBox, QtCore.SIGNAL("valueChanged(int)"), self.greenSlider.setValue)
        QtCore.QObject.connect(self.blueSpinBox, QtCore.SIGNAL("valueChanged(int)"), self.blueSlider.setValue)
        QtCore.QMetaObject.connectSlotsByName(RGBControlWidget)

    def retranslateUi(self, RGBControlWidget):
        RGBControlWidget.setWindowTitle(QtWidgets.QApplication.translate("RGBControlWidget", "RGB Control Widget", None, -1))
        self.whiteButton.setText(QtWidgets.QApplication.translate("RGBControlWidget", "White", None, -1))
        self.redButton.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Red", None, -1))
        self.greenButton.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Green", None, -1))
        self.blueButton.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Blue", None, -1))
        self.cyanButton.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Cyan", None, -1))
        self.magentaButton.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Magenta", None, -1))
        self.yellowButton.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Yellow", None, -1))
        self.blackButton.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Black", None, -1))
        self.blueLabel.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Blue", None, -1))
        self.greenLabel.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Green", None, -1))
        self.redLabel.setText(QtWidgets.QApplication.translate("RGBControlWidget", "Red", None, -1))

